#[non_exhaustive]pub enum RuntimeError {
InvalidInstance(String),
Timeout,
MemoryError,
ParseError(String),
InvalidArgument(String),
UnknownError(String),
}Expand description
Errors thrown by Minion during execution.
These represent internal Minion C++ exceptions translated into Rust.
Invalid usage of this library should throw an error before Minion is even run. Therefore, these should be quite rare. Consider creating an issue on Github if these occur regularly!
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidInstance(String)
The model given to Minion is invalid.
Timeout
The solver exceeded its time limit.
MemoryError
The solver ran out of memory.
ParseError(String)
A parse error occurred (e.g. bad variable name, duplicate name).
InvalidArgument(String)
An invalid argument was provided.
UnknownError(String)
An unknown error has occurred.