pub type MidSearchCallback<'a> = Box<dyn FnMut(&mut MidSearchContext<'_>, HashMap<VarName, Constant>) -> bool + 'a>;Expand description
Richer callback that also receives a MidSearchContext handle so
the caller can add variables or constraints from inside a solution
callback. See run_minion_midsearch.
Aliased Type
pub struct MidSearchCallback<'a>(/* private fields */);Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 16 bytes